@@ -3,9 +3,7 @@ package Promise::XS::Loader;
 use strict;
 use warnings;
 
-use Promise::XS;
-our $VERSION;
-*VERSION = \$Promise::XS::VERSION;
+our $VERSION = '0.01';
 
 require XSLoader;
 XSLoader::load('Promise::XS', $VERSION);
